@@ -307,6 +307,14 @@ class SceneObject(BaseModel):
     stack_target: Optional[bool]
 
 
+class TerminalOutputMode(Enum):
+    ACTIONS = 'actions'
+    MINIMAL = 'minimal'
+    OBJECTS = 'objects'
+    PERFORMER = 'performer'
+    SCENE = 'scene'
+
+
 class ConfigManager:
 
     DEFAULT_ROOM_DIMENSIONS = Vector3d(x=10, y=3, z=10)
@@ -314,24 +322,26 @@ class ConfigManager:
     CONFIG_DEFAULT_SECTION = 'MCS'
     CONFIG_DISABLE_DEPTH_MAPS = 'disable_depth_maps'
     CONFIG_DISABLE_OBJECT_MASKS = 'disable_object_masks'
-    CONFIG_ONLY_RETURN_GOAL_OBJECT = 'only_return_goal_object'
     CONFIG_DISABLE_POSITION = 'disable_position'
     CONFIG_EVALUATION_NAME = 'evaluation_name'
+    CONFIG_GOAL_REWARD = 'goal_reward'
     CONFIG_HISTORY_ENABLED = 'history_enabled'
+    CONFIG_LAVA_PENALTY = 'lava_penalty'
     CONFIG_METADATA_TIER = 'metadata'
     CONFIG_NOISE_ENABLED = 'noise_enabled'
+    CONFIG_ONLY_RETURN_GOAL_OBJECT = 'only_return_goal_object'
     CONFIG_SAVE_DEBUG_IMAGES = 'save_debug_images'
     CONFIG_SAVE_DEBUG_JSON = 'save_debug_json'
     CONFIG_SIZE = 'size'
-    CONFIG_TEAM = 'team'
-    CONFIG_VIDEO_ENABLED = 'video_enabled'
-    CONFIG_LAVA_PENALTY = 'lava_penalty'
-    CONFIG_STEPS_ALLOWED_IN_LAVA = 'steps_allowed_in_lava'
     CONFIG_STEP_PENALTY = 'step_penalty'
-    CONFIG_GOAL_REWARD = 'goal_reward'
+    CONFIG_STEPS_ALLOWED_IN_LAVA = 'steps_allowed_in_lava'
+    CONFIG_TEAM = 'team'
+    CONFIG_TERMINAL_OUTPUT = 'terminal_output'
+    CONFIG_TIMEOUT = 'timeout'
     CONFIG_TOP_DOWN_PLOTTER = 'top_down_plotter'
     CONFIG_TOP_DOWN_CAMERA = 'top_down_camera'
-    CONFIG_TIMEOUT = 'timeout'
+    CONFIG_CONTROLLER_TIMEOUT = 'controller_timeout'
+    CONFIG_VIDEO_ENABLED = 'video_enabled'
 
     # Please keep the aspect ratio as 3:2 because the IntPhys scenes are built
     # on this assumption.
@@ -345,6 +355,9 @@ class ConfigManager:
     # is 1 hour (represented in seconds)
     TIMEOUT_DEFAULT = 3600
 
+    # Default time for initalizing a controller.
+    CONTROLLER_TIMEOUT_DEFAULT = 180
+
     def __init__(self, config_file_or_dict=None):
         '''
         Configuration preferences passed in by the user.
@@ -433,6 +446,34 @@ class ConfigManager:
             fallback=''
         )
 
+    def get_terminal_output_mode(self) -> List[TerminalOutputMode]:
+        try:
+            # If mode is boolean, return all or nothing.
+            terminal_output_mode = self._config.getboolean(
+                self.CONFIG_DEFAULT_SECTION,
+                self.CONFIG_TERMINAL_OUTPUT,
+                fallback=True
+            )
+            if terminal_output_mode:
+                return [mode for mode in TerminalOutputMode]
+            return []
+        except ValueError:
+            # If mode is string, assume comma separated list.
+            terminal_output_mode = self._config.get(
+                self.CONFIG_DEFAULT_SECTION,
+                self.CONFIG_TERMINAL_OUTPUT,
+                fallback=True
+            )
+            if not terminal_output_mode:
+                return []
+            inputs = terminal_output_mode.split(',')
+            if 'all' in inputs or 'ALL' in inputs:
+                return [mode for mode in TerminalOutputMode]
+            return [
+                mode for mode in TerminalOutputMode
+                if mode.value in inputs or mode.value.upper() in inputs
+            ]
+
     def is_history_enabled(self):
         return self._config.getboolean(
             self.CONFIG_DEFAULT_SECTION,
@@ -469,71 +510,32 @@ class ConfigManager:
         )
 
     def is_depth_maps_enabled(self) -> bool:
-        metadata_tier = self.get_metadata_tier()
-
-        allowed_by_config = not self._config.getboolean(
+        return not self._config.getboolean(
             self.CONFIG_DEFAULT_SECTION,
             self.CONFIG_DISABLE_DEPTH_MAPS,
             fallback=False
         )
-        allowed_by_metadata_tier = metadata_tier in [
-            MetadataTier.LEVEL_1,
-            MetadataTier.LEVEL_2,
-            MetadataTier.ORACLE,
-        ]
-        if allowed_by_metadata_tier and allowed_by_config:
-            return True
-        else:
-            return False
 
     def is_only_return_object_goal(self) -> bool:
-        metadata_tier = self.get_metadata_tier()
-        allowed_by_config = self._config.getboolean(
+        return self._config.getboolean(
             self.CONFIG_DEFAULT_SECTION,
             self.CONFIG_ONLY_RETURN_GOAL_OBJECT,
             fallback=False
         )
-        allowed_by_metadata_tier = metadata_tier in [
-            MetadataTier.ORACLE
-        ]
-        if allowed_by_metadata_tier and allowed_by_config:
-            return True
-        else:
-            return False
 
     def is_position_disabled(self) -> bool:
-        metadata_tier = self.get_metadata_tier()
-        allowed_by_config = not self._config.getboolean(
+        return self._config.getboolean(
             self.CONFIG_DEFAULT_SECTION,
             self.CONFIG_DISABLE_POSITION,
             fallback=False
         )
-        allowed_by_metadata_tier = metadata_tier in [
-            MetadataTier.ORACLE
-        ]
-
-        if allowed_by_metadata_tier and allowed_by_config:
-            return False
-        else:
-            return True
 
     def is_object_masks_enabled(self) -> bool:
-        metadata_tier = self.get_metadata_tier()
-        allowed_by_config = not self._config.getboolean(
+        return not self._config.getboolean(
             self.CONFIG_DEFAULT_SECTION,
             self.CONFIG_DISABLE_OBJECT_MASKS,
             fallback=False
         )
-        allowed_by_metadata_tier = (metadata_tier != MetadataTier.LEVEL_1 and
-                                    metadata_tier in
-                                    [
-                                        MetadataTier.LEVEL_2,
-                                        MetadataTier.ORACLE,
-                                    ])
-        if allowed_by_metadata_tier and allowed_by_config:
-            return True
-        else:
-            return False
 
     def get_screen_size(self) -> Tuple[int, int]:
         return (self.get_screen_width(), self.get_screen_height())
@@ -573,6 +575,24 @@ class ConfigManager:
             fallback=self.STEPS_ALLOWED_IN_LAVA_DEFAULT
         )
 
+    def get_controller_timeout(self):
+        """ Time (in seconds) to allow a run to be idle
+        before attempting to end scene"""
+        return self._config.getint(
+            self.CONFIG_DEFAULT_SECTION,
+            self.CONFIG_CONTROLLER_TIMEOUT,
+            fallback=self.CONTROLLER_TIMEOUT_DEFAULT
+        )
+
+    def set_controller_timeout(self, seconds):
+        """ Time (in seconds) to allow a controller to initialization
+        before attempting to end scene"""
+        return self._config.set(
+            self.CONFIG_DEFAULT_SECTION,
+            self.CONFIG_CONTROLLER_TIMEOUT,
+            seconds
+        )
+
     def get_timeout(self):
         """ Time (in seconds) to allow a run to be idle
         before attempting to end scene"""
@@ -582,6 +602,15 @@ class ConfigManager:
             fallback=self.TIMEOUT_DEFAULT
         )
 
+    def set_timeout(self, seconds):
+        """ Setting the time (in seconds) to allow a run to be idle
+        before attempting to end scene"""
+        return self._config.set(
+            self.CONFIG_DEFAULT_SECTION,
+            self.CONFIG_TIMEOUT,
+            seconds
+        )
+
     def is_top_down_plotter(self) -> bool:
         """Toggles whether old plotter should be used to create top down
         videos if videos are enabled."""
@@ -696,6 +725,7 @@ class SceneConfiguration(BaseModel):
             ))
 
         goal = self.goal
+        goal.metadata = goal.metadata or {}
 
         # Transform action list data from strings to tuples.
         action_list = goal.action_list or []
