@@ -37,7 +37,9 @@ def add_subscribers(controller: Controller, config: ConfigManager):
             controller.subscribe(DepthVideoEventHandler())
         if (config.is_object_masks_enabled()):
             controller.subscribe(SegmentationVideoEventHandler())
-    controller.subscribe(ControllerLogger())
+    # Add the logger unless no modes are configured.
+    if config.get_terminal_output_mode():
+        controller.subscribe(ControllerLogger())
     # TODO once we remove evaulation code, we can better handle when,
     # this handler subscribes
     controller.subscribe(HistoryEventHandler())
